# Examples

Here are collected some examples of more complex assemblies for your education and/or inspiration.

## crossed_axis_drive.scad

![](https://raw.githubusercontent.com/dpellegr/PolyGear/master/imgs/crossed_axis_drive.gif "crossed_axes_drive")

## planetary.scad

![](https://raw.githubusercontent.com/dpellegr/PolyGear/master/imgs/planetary.gif "planetary")

## ...

<a rel="license" href="http://creativecommons.org/licenses/by-sa/4.0/"><img alt="Creative Commons License" style="border-width:0" src="https://i.creativecommons.org/l/by-sa/4.0/88x31.png" /></a><br />This work is licensed under a <a rel="license" href="http://creativecommons.org/licenses/by-sa/4.0/">Creative Commons Attribution-ShareAlike 4.0 International License</a>.
